summaryrefslogtreecommitdiffstats
path: root/kalarm/pickfileradio.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/pickfileradio.h')
-rw-r--r--kalarm/pickfileradio.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kalarm/pickfileradio.h b/kalarm/pickfileradio.h
index a8d12383..72b43110 100644
--- a/kalarm/pickfileradio.h
+++ b/kalarm/pickfileradio.h
@@ -38,7 +38,7 @@ class LineEdit;
* To achieve this, whenever the button is newly selected and the
* file name is currently blank, the file picker dialogue is displayed to choose a
* file. If the dialogue exits without a file being chosen, the radio button selection
* is reverted to the previously selected button in the tqparent button group.
*
* The class handles the activation of the file picker dialogue (via a virtual method
* which must be supplied by deriving a class from this one). It also handles all
@@ -56,17 +56,17 @@ class PickFileRadio : public RadioButton
* @param button Push button to invoke the file picker dialogue.
* @param edit File name edit widget, or null if there is none.
* @param text Radio button's text.
* @param tqparent Button group which is to be the tqparent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(TQPushButton* button, LineEdit* edit, const TQString& text, TQButtonGroup* tqparent, const char* name = 0);
+ PickFileRadio(TQPushButton* button, LineEdit* edit, const TQString& text, TQButtonGroup* parent, const char* name = 0);
/** Constructor.
* The init() method must be called before the widget can be used.
* @param text Radio button's text.
* @param tqparent Button group which is to be the tqparent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(const TQString& text, TQButtonGroup* tqparent, const char* name = 0);
+ PickFileRadio(const TQString& text, TQButtonGroup* parent, const char* name = 0);
/** Initialises the widget.
* @param button Push button to invoke the file picker dialogue.
* @param edit File name edit widget, or null if there is none.
@@ -38,7 +38,7 @@ class LineEdit;
* file name is currently blank, the file picker dialogue is displayed to choose a
* file. If the dialogue exits without a file being chosen, the radio button selection
- * is reverted to the previously selected button in the tqparent button group.
+ * is reverted to the previously selected button in the parent button group.
*
* The class handles the activation of the file picker dialogue (via a virtual method
@@ -56,17 +56,17 @@ class PickFileRadio : public RadioButton
* @param edit File name edit widget, or null if there is none.
* @param text Radio button's text.
- * @param tqparent Button group which is to be the tqparent object for the radio button.
+ * @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/
@@ -56,17 +56,17 @@ class PickFileRadio : public RadioButton
* The init() method must be called before the widget can be used.
* @param text Radio button's text.
- * @param tqparent Button group which is to be the tqparent object for the radio button.
+ * @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/